@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2021
-;; Version: 1.8
-;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4") (vertico "1.8"))
+;; Version: 1.9
+;; Package-Requires: ((emacs "27.1") (compat "30") (vertico "1.9"))
 ;; Homepage: https://github.com/minad/vertico
 
 ;; This file is part of GNU Emacs.
@@ -180,7 +180,9 @@
                   (set-window-parameter win 'no-delete-other-windows old-no-delete)
                   (set-window-dedicated-p win nil)
                   (set-window-buffer win old-buf))
-                 ((window-live-p win)
+                 ;; Check `window-parent' since the window may be a sole window
+                 ;; (gh:minad/vertico#496).
+                 ((and (window-live-p win) (window-parent win))
                   (delete-window win)))
                 (when vertico-buffer-hide-prompt
                   (set-window-vscroll nil 0))))))
