@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2021
-;; Version: 1.8
-;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4") (vertico "1.8"))
+;; Version: 1.9
+;; Package-Requires: ((emacs "27.1") (compat "30") (vertico "1.9"))
 ;; Homepage: https://github.com/minad/vertico
 
 ;; This file is part of GNU Emacs.
@@ -116,10 +116,5 @@ Exit with current input if prefix ARG is given."
                      (eq ?/ (char-before (- (point) 2)))))
         (delete-region (overlay-start ov) (overlay-end ov))))))
 
-;; Emacs 28: Do not show Vertico commands in M-X
-(dolist (sym '(vertico-directory-up vertico-directory-enter
-               vertico-directory-delete-char vertico-directory-delete-word))
-  (put sym 'completion-predicate #'vertico--command-p))
-
 (provide 'vertico-directory)
 ;;; vertico-directory.el ends here
